<?php

function get_duplicated_templates() {
    return array('HomeTemplate' => true, 'BlogTemplate' => true, 'SinglePostTemplate' => true, 'PageTemplate' => true, 'ForumTemplate' => true, 'CustomTemplate' => true, 'DefaultTemplate' => true, 'Template404' => true);
}

function get_templates_dir($theme_dir) {
    return $theme_dir . '/templates';
}

function get_template_name_pattern() {
    return '/-+/i';
}

function get_version_separators() {
    return array('d8' => '--');
}

function remove_theme_page_file($file_info, $theme_dir, &$changed_files) {
    $templates_dir = get_templates_dir($theme_dir);
    $name = $file_info['filename'];
    $basename = $file_info['basename'];
    $files = array();
    $separators = get_version_separators();
    $custom_pattern = get_template_name_pattern();
    foreach ($separators as $version => $separator) {
        // common templates
        $files[] = $templates_dir . '/html/html' . $separator . $name .'.html.twig';
        $files[] = $templates_dir . '/page/page' . $separator . $name .'.html.twig';
        // custom templates
        $custom_name = preg_replace($custom_pattern, $separator, $basename);
        $custom_name = str_replace('page' . $separator, '', $custom_name);
        $files[] = $templates_dir . '/page/page' . $separator . $custom_name;
        $files[] = $templates_dir . '/html/html' . $separator . $custom_name;
    }

    foreach ($files as $file) {
        if (is_file($file)) {
            FilesHelper::delete_file($file);
            $changed_files[] = $file; // remove Drupal template files from both base and preview themes
        }
    }
}

function build_theme_page_file($content, $file_info, $theme_dir, &$changed_files) {
    $to_save = array();
    $templates_dir = get_templates_dir($theme_dir);
    $name = $file_info['filename'];

    if (strpos($name, 'page-') !== false) {// custom template - validated name as 'page-{template_name}.tpl' from $file_info['filename'], not '.tpl.php'
        $clear_name = str_replace('.html', '', $name);
        $custom_pattern = get_template_name_pattern();
        $separators = get_version_separators();
        foreach ($separators as $version => $separator) {
            $custom_name = preg_replace($custom_pattern, $separator, $clear_name);
            $custom_name = str_replace('page' . $separator, '', $custom_name);
            save_template_file($content, $custom_name, $templates_dir, $changed_files, $version);
        }   
    } else { // all other templates - {template_name}.html, $name= {template_name}
        save_template_file($content, $name, $templates_dir, $changed_files);
    }
}

function save_template_file($content, $name, $templates_dir, &$changed_files, $version = '') {
    $to_save = parse_content($content, $name, $templates_dir);

    if (strpos($name, 'default') !== false) { // always save the whole content to maintenance page as last default template
        $to_save[] = array('path' => $templates_dir . '/page/maintenance-page.html.twig', 'content' => $content);
    }

    foreach ($to_save as $save) {
        save_to_change($save['path'], $save['content'], $changed_files);
    }
}

function parse_content($content, $name, $templates_dir) {
    $html_content = "\n{{ page_top }}\n{{ page }}\n{{ page_bottom }}\n<js-bottom-placeholder token=\"{{ placeholder_token|raw }}\">\n";
    $pattern = '/(.*?<body.*?>)(.*?)(<\/body.*?html>)/si';
    $page = preg_replace($pattern, '$2', $content);
    $html = preg_replace($pattern, '$1'.$html_content.'$3', $content);
    return array(array('path' => $templates_dir . '/html/html--' . $name .'.html.twig', 'content' => $html),
                 array('path' => $templates_dir . '/page/page--' . $name .'.html.twig', 'content' => $page));
}